
/*****************************************************************************\
 *                              Simple Effect
\*****************************************************************************/

/*! @file SimpleEffect.h
 *
 *  @brief
 *	A simple effect class
 *   
 *  @author Abe
 *     
 */

/*
    Copyright  2001 Ibragium Kouliev All Rights Reserved.
 
 	This file is part of GL Effects Framework.
 
    GL Effects Framework is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    GL Effects Framework is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with GL Effects Framework; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

/*! @class SimpleEffect
 *
 * @ingroup appclasses
 *
 * @brief 
 *
 *   
 **/

#ifndef SIMPLEEFFECT_H
#define SIMPLEEFFECT_H

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

//---------------------------------------------------------------------------
//  Includes
//---------------------------------------------------------------------------

// system library headers
#include <stdio.h>
#include <stdlib.h>

// Local headers

// GLEffect.h must ALWAYS be included!
#include "GLEffect.h" 

//---------------------------------------------------------------------------
//  Forward references
//---------------------------------------------------------------------------

// controls classes

/* This is just a convenient way to group things together. You can
put all forward references to Qt control widgets here */
class QTimer;

// geometry management classes
/* Here go any necessary references to Qt geometry management widgets, i.e
QGroupBox etc. */

//**************************************************************************
// Simple Effect
//**************************************************************************

class SimpleEffect: public GLEffect
{
	Q_OBJECT

//---------------------------------------------------------------------------
//  Public Instance Methods
//---------------------------------------------------------------------------
public:

// --------------------------------------------------------------------------
//! @name  Creation, desctruction
// @{

	//! Primary class contructor
	SimpleEffect(GLFramework* parent);
	
	//! Destructor
	virtual ~SimpleEffect();
	
// --------------------------------------------------------------------------
// @} 

//! @name Public API functions
// @{


	//! Creates control widgets that will manipulate effect parameters & 
	//behaviour. 
	void createControls(QWidget* parentWindow);


// --------------------------------------------------------------------------
// @}

/** @name Rendering, animation and effect control functions */
	
// @{		  
		//! Stops animation.
		virtual void stop();
		
		//! Starts animation.
		virtual void play();
		
		//! Resets the effect's parameters.
		virtual void reset();

		//! Pauses animation.
		virtual void pause();
		
		//! Effect-specific implementation of the rendering routine.
		virtual void render();
// --------------------------------------------------------------------------
// @} 

//! @name Event handlers 
// @{ 
		
		/* Event handlers here are disabled by default and you don't 
		have to reimplement them if base class implementations are 
		sufficient for your needs. Otherwise, uncomment those you
		need and override them in your class. */


		//! Mouse move events handler.
		//virtual void mouseMoveEvent(QMouseEvent*);
		//! Mouse click events handler.
		//virtual void mousePressEvent(QMouseEvent*);
		//! Keyboard events handler.
		//virtual void keyPressEvent(QKeyEvent*);

// --------------------------------------------------------------------------
// @} 


// --------------------------------------------------------------------------
//! @name	Signals:
// @{ 
	
	signals:

// --------------------------------------------------------------------------
// @}

//! @name	Slots:
// @{

	public slots:  
	
	private slots:

		void animate();

// --------------------------------------------------------------------------
// @}


//---------------------------------------------------------------------------
//  Private/Protected Instance Methods
//---------------------------------------------------------------------------

protected:

	//! Initializes effect states and parameters.
	virtual void initialize(); 
	

private:

//---------------------------------------------------------------------------
//  Private/Protected Instance Variables
//---------------------------------------------------------------------------

private:

	// Disabled default constructor and assignment operator
	SimpleEffect();
	SimpleEffect& operator = (const SimpleEffect& source);

// --------------------------------------------------------------------------
//@! name Member controls
//@{


// --------------------------------------------------------------------------
//@}


//@! name Member Variables
//@{
	QTimer* effectTimer; //! used to animate effect

	GLdouble rotationAngle; //! current rotation angle 
	GLdouble angleDelta; // rotation angle increment

	GLuint texture; //! Texture object 

	
// --------------------------------------------------------------------------
//@}

//---------------------------------------------------------------------------
//  Class methods and variables
//---------------------------------------------------------------------------

};

#endif


